Class-Reference - XTS Client API Documentation

# Class Reference

This page contains the syntex & patameter requirements for each function/method of the package.

## XTS_Connect

::: xts_api_client.xts_connect

## interactive_socket_client

::: xts_api_client.interactive_socket_client

## interactive_socket

::: xts_api_client.interactive_socket

## market_data_socket_client

::: xts_api_client.market_data_socket_client

## market_data_socket

::: xts_api_client.market_data_socket

#### Search

From here you can search these documents. Enter your search terms below.

#### Keyboard Shortcuts

Keys | Action
--- | ---
`?` | Open this help
`n` | Next page
`p` | Previous page
`s` | Search